@@ -14,13 +14,15 @@
 
 from __future__ import annotations
 
+import importlib
 import os
 
 import firefly as ff
-import firefly_survey.domain as domain
 
 secured = False if os.environ.get('ANONYMOUS_ACCESS', 'false') in (True, 'true', 1, '1') else True
 
+domain = importlib.import_module(f'{os.environ.get("CONTEXT")}.domain')
+
 
 @ff.rest('/documents', method='POST', secured=secured)
 class CreateDocument(ff.ApplicationService):
@@ -31,8 +33,10 @@ class CreateDocument(ff.ApplicationService):
         documents = self._registry(domain.Document)
 
         schema = schemas.find(schema)
-        print(schema)
         if schema is None:
             raise ff.NotFound()
 
-        documents.append(domain.Document(schema=schema, data=data))
+        params = {'schema': schema, 'data': data}
+        params.update(kwargs)
+
+        documents.append(domain.Document.from_dict(params))
